==> komclean-1.1.0.tbz: share/komclean/html/komimsg.js <==
var current_instant_message_view = -1;
var unread_instant = new Array();
var unread_instant_msgid = new Array();

function kom_has_unread_instant()
{
	return (unread_instant && unread_instant.length > 0);
}

function kom_view_instant_messages(id)
{
	document.getElementById(kom_threadview_name).style.display = "none";
	document.getElementById(kom_instantmessageview_name).style.display = "block";

	if (id == undefined)
	{
		document.getElementById("imessview_starter").style.display = "block";
		document.getElementById("imessview_container").style.display = "none";
		
		highlight_menu_item("menu_new_chat");
	}
	else
	{
		document.getElementById("imessview_starter").style.display = "none";
		document.getElementById("imessview_container").style.display = "block";

		highlight_menu_item("imesstitle_" + id);
	}
}

function kom_view_next_unread_instant_message()
{
	if (unread_instant && unread_instant.length > 0)
	{
		kom_activate_instant_message_view(unread_instant[0]);
		return 1;
	}
	return 0;
}

function kom_send_instant_message(to, text)
{
	var re = kom_command("send_instant_message " + to + " " + KOM_RECORD_SEPARATOR + text + KOM_RECORD_SEPARATOR).split(KOM_GROUP_SEPARATOR);
	if (re[0] != "OK")
	{
		var elm = document.getElementById("imessview_" + to);
		if (elm)
			kom_output_message(elm, "*Message could not be delivered ("+re[1]+")* \""+text+"\"<br>");
	}
}

function kom_init_instant_message_starter()
{
	var elm = document.getElementById("imessview_starter");
	elm.innerHTML = "";
	var search = createConferenceSelector(true, true);
	elm.appendChild(search);
	elm.innerHTML += "<input type='button' value='Start chat' onclick='start_new_instant_message_session(\""+search.getAttribute("id")+"\");return false;'>";
}
function start_new_instant_message_session(id)
{
	var conf = getSelectedConference(id);
	if (conf > 0)
	{
		kom_add_instant_message(0, -1, conf, '', 0, 1);
		kom_activate_instant_message_view(conf);
		resetConferenceSelector(id);
	}
}

function kom_activate_instant_message_view(id)
{
	if (id != current_instant_message_view)
	{
		var elm = document.getElementById("imessview_" + id);
		if (!elm)
			return;
		elm.style.display = "block";
		document.getElementById("instant_message_text_form_"+id).style.display = "block";
		elm = document.getElementById("imessview_" + current_instant_message_view);
		if (elm)
		{
			unhighlight_item(document.getElementById("imesstitle_"+current_instant_message_view));
			elm.style.display = "none";
			document.getElementById("instant_message_text_form_"+current_instant_message_view).style.display = "none";
		}
		current_instant_message_view = id;
	}

	kom_view_instant_messages(id);

	for (var i = 0; i < unread_instant.length; ++i)
	{
		if (unread_instant[i] == id)
		{
			kom_command("mark_instant_message_read " + unread_instant_msgid[i]);
			unread_instant.splice(i);
			unread_instant_msgid.splice(i);
			i--;
		}
	}
	document.getElementById("imesstitle_"+id).className = document.getElementById("imesstitle_"+id).className.replace(/ unread/g, "");
	kom_update_favicon();
}

function kom_add_instant_message(msgid, from, to, text, timestamp, read)
{
	if (to < 0)
	{
		to = from;
	}
	
	var msglistelm = document.getElementById("imesslistview");
	var msgviewelm = document.getElementById("imessview_container");
	var elm = document.getElementById("imessview_" + to);
	if (!elm)
	{
		var name = kom_lookup_name(to);
		elm = document.createElement("div");
		elm.setAttribute("class", "menuitem");
		elm.setAttribute("id", "imesstitle_" + to);
		elm.setAttribute("onClick", "kom_activate_instant_message_view(" + to + ");");
		elm.innerHTML = name;
		msglistelm.appendChild(elm);
		elm = document.createElement("div");
		elm.setAttribute("id", "imessview_" + to);
		elm.setAttribute("class", "instant_message_output");
		msgviewelm.appendChild(elm);
		var inputelm = document.createElement("div");
		inputelm.setAttribute("id", "instant_message_text_form_"+to)
		inputelm.innerHTML = "<form onkeydown=\"kom_cancel_key(event);\" "+
			"onsubmit=\"kom_send_instant_message(current_instant_message_view, "+
			"document.getElementById('kom_instant_message_text_"+to+"').value);"+
			"document.getElementById('kom_instant_message_text_"+to+"').value='';"+
			"return false;\">\n"+
			"<input type='text' value='' id='kom_instant_message_text_"+to+
				"' onkeydown='kom_cancel_key(event);' class='kom_instant_message_text'>\n"+
			"<input type='submit' value='Send'>\n"+
			"</form>";

		msgviewelm.appendChild(inputelm);
		elm.style.display="none";
		inputelm.style.display="none";
	}
	// If this is not a valid from address, just return
	if (from < 0 || current_instant_message_view < 0)
	{
		//kom_activate_instant_message_view(to);
	}
	if (from < 0)
		return;
	var name = kom_lookup_name(from);
	text = kom_postprocess_message(text).replace(/\n/g, "<br>");
	var class = (from == to) ? "this_user" : "other_user";
	var recvtime = new Date(timestamp*1000);
	kom_output_message(elm, "<div class='" + class + "'><span>["+recvtime.toTimeString().substring(0,8)+"]</span> &lt;<span>" + name + "</span>&gt; " + text + "</div>");

	// If already read, return
	if (read)
		return;
	if (document.getElementById(kom_instantmessageview_name).style.display == "block" &&
		document.getElementById("imessview_container").style.display == "block" &&
		current_instant_message_view == to)
	{
		kom_command("mark_instant_message_read " + msgid);
		return;
	}
	for (var i = 0; i < unread_instant.length; ++i)
	{
		if (unread_instant[i] == to)
		{
			kom_command("mark_instant_message_read " + unread_instant_msgid[i]);
			unread_instant_msgid[i] = msgid;
			return;
		}
	}
	unread_instant.push(to);
	unread_instant_msgid.push(msgid);
	document.getElementById("imesstitle_"+to).setAttribute("class", "menuitem unread");
	kom_update_favicon();
}

function kom_output_message(parent, message)
{
	parent.innerHTML += message;

	// Scroll to bottom
	parent.scrollTop = parent.scrollHeight;
}

==> komclean-1.2.0.tbz: share/komclean/html/komimsg.js <==
var current_instant_message_view = -1;
var unread_instant = new Array();
var unread_instant_msgid = new Array();

function kom_has_unread_instant()
{
	return (unread_instant && unread_instant.length > 0);
}

function kom_view_instant_messages(id)
{
	document.getElementById(kom_threadview_name).style.display = "none";
	document.getElementById(kom_instantmessageview_name).style.display = "block";

	if (id == undefined)
	{
		kom_update_online_user_list();
		document.getElementById("imessview_starter").style.display = "block";
		document.getElementById("imessview_container").style.display = "none";
		
		highlight_menu_item("menu_new_chat");
	}
	else
	{
		document.getElementById("imessview_starter").style.display = "none";
		document.getElementById("imessview_container").style.display = "block";

		highlight_menu_item("imesstitle_" + id);
	}
}

function kom_view_next_unread_instant_message()
{
	if (unread_instant && unread_instant.length > 0)
	{
		kom_activate_instant_message_view(unread_instant[0]);
		return 1;
	}
	return 0;
}

function kom_send_instant_message(to, text)
{
	var re = kom_command("send_instant_message " + to + " " + KOM_RECORD_SEPARATOR + text + KOM_RECORD_SEPARATOR).split(KOM_GROUP_SEPARATOR);
	if (re[0] != "OK")
	{
		var elm = document.getElementById("imessview_" + to);
		if (elm)
			kom_output_message(elm, "*Message could not be delivered ("+re[1]+")* \""+text+"\"<br>");
	}
}

function kom_online_user_sort(a, b)
{
	a = kom_lookup_name(a.split(KOM_RECORD_SEPARATOR)[0]).toLowerCase();
	b = kom_lookup_name(b.split(KOM_RECORD_SEPARATOR)[0]).toLowerCase();
	a = a.replace(/\([^\)]*\)/g, "");
	a = a.replace(/^\s+/, "");
	b = b.replace(/\([^\)]*\)/g, "");
	b = b.replace(/^\s+/, "");
	if (a < b)
		return -1;
	if (a > b)
		return 1;
	return 0;
}

function kom_update_online_user_list()
{
	var elm = document.getElementById('imessview_online_user_list');

	kom_begin_progress();
	var userList = kom_command("list_all_online_users").split(KOM_GROUP_SEPARATOR);
	if (userList[0] != "OK" || userList.length < 2)
	{
		kom_end_progress();
		elm.innerHTML = "";
		return;
	}
	userList.splice(0, 1);
	// Prefetch all names to avoid reflowing much while layouting the page
	var prefetch_id = new Array();
	for (var i = 0; i < userList.length; ++i)
	{
		var user = userList[i].split(KOM_RECORD_SEPARATOR);
		prefetch_id.push(user[0]);
		if (user[1] > 0)
			prefetch_id.push(user[1]);
	}
	kom_prefetch_names(prefetch_id);
	elm.innerHTML = "<h2>Online Users</h2>";
	userList.sort(kom_online_user_sort);
	for (var i = 0; i < userList.length; ++i)
	{
		var user = userList[i].split(KOM_RECORD_SEPARATOR);
		var entry = document.createElement("div");
		entry.setAttribute("onClick", "kom_add_instant_message(0, -1, "+user[0]+", '', 0, 1);kom_activate_instant_message_view("+user[0]+");return false;");
		entry.setAttribute("class", "kom_online_user_item");
		
		var idleStr = "";
		var idleTime = parseInt(user[2]);
		if (idleTime > 0)
		{
			idleStr = "<span class='kom_user_idle_time'>Idle";
			if (idleTime >= 60)
			{
				idleTime = parseInt(idleTime/60);
				if (idleTime >= 60)
				{
					idleHours = parseInt(idleTime/60);
					idleTime -= idleHours*60;
					if (idleHours >= 24)
					{
						idleDays = parseInt(idleHours/24);
						idleHours -= idleDays*24;
						idleStr += " " + idleDays + " day" + (idleDays!=1?"s":"");
					}
					idleStr += " " + idleHours + " hour" + (idleHours!=1?"s":"");
				}
				idleStr += " " + idleTime + " minute" + (idleTime!=1?"s":"");
			}
			else
				idleStr += " " + idleTime + " second" + (idleTime!=1?"s":"");
			idleStr += "</span>";
		}
		var confStr = "";
		if (user[1] > 0)
		{
			confStr = "In conference "+kom_lookup_name(user[1]);
			if (user[3] != "")
				confStr += " - " + user[3];
		}
		else if (user[3] != "")
			confStr = user[3];
		
		entry.innerHTML = "<div style='float:left;'>"+kom_lookup_name(user[0]) + "</div><div style='float:right;'>" + confStr + idleStr + "</div>&nbsp;";
		elm.appendChild(entry);
	}
	kom_end_progress();
}

function kom_init_instant_message_starter()
{
	var elm = document.getElementById("imessview_starter");
	elm.innerHTML = "";
	var search = createConferenceSelector(true, true);
	elm.appendChild(search);
	elm.innerHTML += "<input type='button' value='Start chat' onclick='start_new_instant_message_session(\""+search.getAttribute("id")+"\");return false;'>";
	elm.innerHTML += "<div id='imessview_online_user_list'></div>"
}
function start_new_instant_message_session_byconf(conf)
{
	if (conf > 0)
	{
		kom_add_instant_message(0, -1, conf, '', 0, 1);
		kom_activate_instant_message_view(conf);
		resetConferenceSelector(id);
	}
}
function start_new_instant_message_session(id)
{
	start_new_instant_message_session_byconf(getSelectedConference(id));
}

function kom_activate_instant_message_view(id)
{
	if (id != current_instant_message_view)
	{
		var elm = document.getElementById("imessview_" + id);
		if (!elm)
			return;
		elm.style.display = "block";
		document.getElementById("instant_message_text_form_"+id).style.display = "block";
		elm = document.getElementById("imessview_" + current_instant_message_view);
		if (elm)
		{
			unhighlight_item(document.getElementById("imesstitle_"+current_instant_message_view));
			elm.style.display = "none";
			document.getElementById("instant_message_text_form_"+current_instant_message_view).style.display = "none";
		}
		current_instant_message_view = id;
	}

	kom_view_instant_messages(id);

	for (var i = 0; i < unread_instant.length; ++i)
	{
		if (unread_instant[i] == id)
		{
			kom_command("mark_instant_message_read " + unread_instant_msgid[i]);
			unread_instant.splice(i, 1);
			unread_instant_msgid.splice(i, 1);
			i--;
		}
	}
	document.getElementById("imesstitle_"+id).className = document.getElementById("imesstitle_"+id).className.replace(/ unread/g, "");
	kom_update_favicon();
}

function kom_add_instant_message(msgid, from, to, text, timestamp, read)
{
	if (to < 0)
	{
		to = from;
	}
	
	var msglistelm = document.getElementById("imesslistview");
	var msgviewelm = document.getElementById("imessview_container");
	var elm = document.getElementById("imessview_" + to);
	if (!elm)
	{
		var name = kom_lookup_name(to);
		elm = document.createElement("div");
		elm.setAttribute("class", "menuitem");
		elm.setAttribute("id", "imesstitle_" + to);
		elm.setAttribute("onClick", "kom_activate_instant_message_view(" + to + ");");
		elm.innerHTML = name;
		msglistelm.appendChild(elm);
		elm = document.createElement("div");
		elm.setAttribute("id", "imessview_" + to);
		elm.setAttribute("class", "instant_message_output");
		msgviewelm.appendChild(elm);
		var inputelm = document.createElement("div");
		inputelm.setAttribute("id", "instant_message_text_form_"+to)
		inputelm.innerHTML = "<form onkeydown=\"kom_cancel_key(event);\" "+
			"onsubmit=\"kom_send_instant_message(current_instant_message_view, "+
			"document.getElementById('kom_instant_message_text_"+to+"').value);"+
			"document.getElementById('kom_instant_message_text_"+to+"').value='';"+
			"return false;\">\n"+
			"<input type='text' value='' id='kom_instant_message_text_"+to+
				"' onkeydown='kom_cancel_key(event);' class='kom_instant_message_text'>\n"+
			"<input type='submit' value='Send'>\n"+
			"</form>";

		msgviewelm.appendChild(inputelm);
		elm.style.display="none";
		inputelm.style.display="none";
	}
	// If this is not a valid from address, just return
	if (from < 0 || current_instant_message_view < 0)
	{
		//kom_activate_instant_message_view(to);
	}
	if (from < 0)
		return;
	var name = kom_lookup_name(from);
	text = kom_postprocess_message(text).replace(/\n/g, "<br>");
	var class = (from == to) ? "this_user" : "other_user";
	var recvtime = new Date(timestamp*1000);
	kom_output_message(elm, "<div class='" + class + "'><span>["+recvtime.toTimeString().substring(0,8)+"]</span> &lt;<span>" + name + "</span>&gt; " + text + "</div>");

	// If already read, return
	if (read)
		return;
	if (document.getElementById(kom_instantmessageview_name).style.display == "block" &&
		document.getElementById("imessview_container").style.display == "block" &&
		current_instant_message_view == to)
	{
		kom_command("mark_instant_message_read " + msgid);
		return;
	}
	for (var i = 0; i < unread_instant.length; ++i)
	{
		if (unread_instant[i] == to)
		{
			kom_command("mark_instant_message_read " + unread_instant_msgid[i]);
			unread_instant_msgid[i] = msgid;
			return;
		}
	}
	unread_instant.push(to);
	unread_instant_msgid.push(msgid);
	document.getElementById("imesstitle_"+to).setAttribute("class", "menuitem unread");
	kom_update_favicon();
}

function kom_output_message(parent, message)
{
	parent.innerHTML += message;

	// Scroll to bottom
	parent.scrollTop = parent.scrollHeight;
}
